@@ -246,6 +246,7 @@ enum {
   SPVM_OPCODE_C_ID_MOVE_FLOAT,
   SPVM_OPCODE_C_ID_MOVE_DOUBLE,
   SPVM_OPCODE_C_ID_MOVE_OBJECT,
+  SPVM_OPCODE_C_ID_MOVE_UNDEF,
   SPVM_OPCODE_C_ID_MOVE_REF,
   SPVM_OPCODE_C_ID_CONVERT_BYTE_TO_SHORT,
   SPVM_OPCODE_C_ID_CONVERT_BYTE_TO_INT,
@@ -324,6 +325,10 @@ enum {
   SPVM_OPCODE_C_ID_LE_LONG,
   SPVM_OPCODE_C_ID_LE_FLOAT,
   SPVM_OPCODE_C_ID_LE_DOUBLE,
+  SPVM_OPCODE_C_ID_CMP_INT,
+  SPVM_OPCODE_C_ID_CMP_LONG,
+  SPVM_OPCODE_C_ID_CMP_FLOAT,
+  SPVM_OPCODE_C_ID_CMP_DOUBLE,
   SPVM_OPCODE_C_ID_IS_UNDEF,
   SPVM_OPCODE_C_ID_IS_NOT_UNDEF,
   SPVM_OPCODE_C_ID_STRING_EQ,
@@ -332,6 +337,7 @@ enum {
   SPVM_OPCODE_C_ID_STRING_GE,
   SPVM_OPCODE_C_ID_STRING_LT,
   SPVM_OPCODE_C_ID_STRING_LE,
+  SPVM_OPCODE_C_ID_STRING_CMP,
   SPVM_OPCODE_C_ID_BOOL_INT,
   SPVM_OPCODE_C_ID_BOOL_LONG,
   SPVM_OPCODE_C_ID_BOOL_FLOAT,
