@@ -10,8 +10,8 @@ SPVM::Cloner - a callback type to clone a object
   
   use SPVM::Cloner;
   
-  my $cloner : SPVM::Cloner = sub : object ($self : self, $obj : object) {
-    my $point = (SPVM::Point)$obj;
+  my $cloner : SPVM::Cloner = sub : object ($self : self, $object : object) {
+    my $point = (SPVM::Point)$object;
     
     my $new_point = SPVM::Point->new($point->x, $point->y);
     
@@ -25,8 +25,10 @@ SPVM::Cloner - a callback type to clone a object
 
 L<SPVM::Cloner> is a callback type to clone a object.
 
-=head1 CALLBACK METHOD
+=head1 CALLBACK METHOD INTERFACE
 
-  sub : object ($self : self, $obj : object);
+  sub : object ($self : self, $object : object);
 
-This method should be cloned object in the method implementation.
+This method clone object.
+
+This method is planned to be implemented in other classes.
