@@ -24,5 +24,5 @@ L<SPVM::Comparator> is a callback type to compare two numbers.
 
   sub : int ($self : self, $a : int, $b : int);
 
-This method should receive two numbers and return 1 if $a is more than $b, -1 if $x is lass than $b, 0 if $a equals $b in the implementation.
+This method should receive two numbers and return 1 if $a is more than $b, -1 if $x is less than $b, 0 if $a equals $b in the implementation.
 
