@@ -12,37 +12,37 @@ SPVM::Sort - Sort functions
   
   # Sort byte array itself by asc order
   my $nums = [(byte)2, 3, 1];
-  SPVM::Sort::sortb($nums, 0, scalar @$nums, sub : int ($self : self, $a : byte, $b : byte) {
+  SPVM::Sort->sort_byte($nums, 0, scalar @$nums, sub : int ($self : self, $a : byte, $b : byte) {
     return $a <=> $b;
   });
 
   # Sort short array itself by asc order
   my $nums = [(short)2, 3, 1];
-  SPVM::Sort::sorts($nums, 0, scalar @$nums, sub : int ($self : self, $a : short, $b : short) {
+  SPVM::Sort->sort_short($nums, 0, scalar @$nums, sub : int ($self : self, $a : short, $b : short) {
     return $a <=> $b;
   });
 
   # Sort int array itself by asc order
   my $nums = [2, 3, 1];
-  SPVM::Sort::sorti($nums, 0, scalar @$nums, sub : int ($self : self, $a : int, $b : int) {
+  SPVM::Sort->sort_int($nums, 0, scalar @$nums, sub : int ($self : self, $a : int, $b : int) {
     return $a <=> $b;
   });
 
   # Sort long array itself by asc order
   my $nums = [(long)2, 3, 1];
-  SPVM::Sort::sortl($nums, 0, scalar @$nums, sub : int ($self : self, $a : long, $b : long) {
+  SPVM::Sort->sort_long($nums, 0, scalar @$nums, sub : int ($self : self, $a : long, $b : long) {
     return $a <=> $b;
   });
 
   # Sort float array itself by asc order
   my $nums = [(float)2, 3, 1];
-  SPVM::Sort::sortf($nums, 0, scalar @$nums, sub : int ($self : self, $a : float, $b : float) {
+  SPVM::Sort->sort_float($nums, 0, scalar @$nums, sub : int ($self : self, $a : float, $b : float) {
     return $a <=> $b;
   });
 
   # Sort double array itself by asc order
   my $nums = [(double)2, 3, 1];
-  SPVM::Sort::sortd($nums, 0, scalar @$nums, sub : int ($self : self, $a : double, $b : double) {
+  SPVM::Sort->sort_double($nums, 0, scalar @$nums, sub : int ($self : self, $a : double, $b : double) {
     return $a <=> $b;
   });
 
@@ -57,7 +57,7 @@ SPVM::Sort - Sort functions
   $minimals->[2] = TestCase::Minimal->new;
   $minimals->[2]{x} = 2;
   $minimals->[2]{y} = 9;
-  SPVM::Sort::sort_obj($minimals, 0, scalar @$minimals, sub : int ($self : self, $object1 : object, $object2 : object) {
+  SPVM::Sort->sort_object$minimals, 0, scalar @$minimals, sub : int ($self : self, $object1 : object, $object2 : object) {
     my $minimal1 = (TestCase::Minimal)$object1;
     my $minimal2 = (TestCase::Minimal)$object2;
     
@@ -70,9 +70,9 @@ L<SPVM::Sort> defines sort functions
 
 =head1 STATIC METHODS
 
-=head2 sortb
+=head2 sort_byte
 
-    sub sortb : void ($nums : byte[], $offset : int, $length : int, $comparator : SPVM::Comparator::Byte)
+    sub sort_byte : void ($nums : byte[], $offset : int, $length : int, $comparator : SPVM::Comparator::Byte)
 
 Sort byte array itself with a offset, a length, and a L<SPVM::Comparator::Byte> comparator.
 
@@ -84,9 +84,9 @@ Length must be more than or equals to 0. Otherwise a exception occurs.
 
 Offset + Length must be in the array range. Otherwise a exception occurs.
 
-=head2 sorts
+=head2 sort_short
 
-    sub sorts : void ($nums : short[], $offset : int, $length : int, $comparator : SPVM::Comparator::Short)
+    sub sort_short : void ($nums : short[], $offset : int, $length : int, $comparator : SPVM::Comparator::Short)
 
 Sort short array itself with a offset, a length, and a L<SPVM::Comparator::Short> comparator.
 
@@ -98,9 +98,9 @@ Length must be more than or equals to 0. Otherwise a exception occurs.
 
 Offset + Length must be in the array range. Otherwise a exception occurs.
 
-=head2 sorti
+=head2 sort_int
 
-    sub sorti : void ($nums : int[], $offset : int, $length : int, $comparator : SPVM::Comparator::Int)
+    sub sort_int : void ($nums : int[], $offset : int, $length : int, $comparator : SPVM::Comparator::Int)
 
 Sort int array itself with a offset, a length, and a L<SPVM::Comparator::Int> comparator.
 
@@ -112,9 +112,9 @@ Length must be more than or equals to 0. Otherwise a exception occurs.
 
 Offset + Length must be in the array range. Otherwise a exception occurs.
 
-=head2 sortl
+=head2 sort_long
 
-    sub sortl : void ($nums : long[], $offset : int, $length : int, $comparator : SPVM::Comparator::Long)
+    sub sort_long : void ($nums : long[], $offset : int, $length : int, $comparator : SPVM::Comparator::Long)
 
 Sort long array itself with a offset, a length, and a L<SPVM::Comparator::Long> comparator.
 
@@ -126,9 +126,9 @@ Length must be more than or equals to 0. Otherwise a exception occurs.
 
 Offset + Length must be in the array range. Otherwise a exception occurs.
 
-=head2 sortf
+=head2 sort_float
 
-    sub sub sortf : void ($nums : float[], $offset : int, $length : int, $comparator : SPVM::Comparator::Float)
+    sub sub sort_float : void ($nums : float[], $offset : int, $length : int, $comparator : SPVM::Comparator::Float)
 
 Sort float array itself with a offset, a length, and a L<SPVM::Comparator::Float> comparator.
 
@@ -140,9 +140,9 @@ Length must be more than or equals to 0. Otherwise a exception occurs.
 
 Offset + Length must be in the array range. Otherwise a exception occurs.
 
-=head2 sortd
+=head2 sort_double
 
-    sub sortd : void ($nums : double[], $offset : int, $length : int, $comparator : SPVM::Comparator::Double)
+    sub sort_double : void ($nums : double[], $offset : int, $length : int, $comparator : SPVM::Comparator::Double)
 
 Sort double array itself with a offset, a length, and a L<SPVM::Comparator::Double> comparator.
 
@@ -154,9 +154,9 @@ Length must be more than or equals to 0. Otherwise a exception occurs.
 
 Offset + Length must be in the array range. Otherwise a exception occurs.
 
-=head2 sorto
+=head2 sort_object
 
-    sub sorto : void ($objs : oarray, $offset : int, $length : int, $comparator : SPVM::Comparator::Object)
+    sub sort_object : void ($objs : oarray, $offset : int, $length : int, $comparator : SPVM::Comparator::Object)
 
 Sort object array itself with a offset, a length, and a L<SPVM::Comparator::Object> comparator.
 
